@@ -6,14 +6,15 @@
     on DBT_INTERNAL_SOURCE.dbt_scd_id = DBT_INTERNAL_DEST.dbt_scd_id
 
     when matched
-     --and DBT_INTERNAL_DEST.dbt_valid_to is null
-     --and DBT_INTERNAL_SOURCE.dbt_change_type = 'update'
         then update
         set dbt_valid_to = DBT_INTERNAL_SOURCE.dbt_valid_to
+        where
+            DBT_INTERNAL_DEST.dbt_valid_to is null
+            and DBT_INTERNAL_SOURCE.dbt_change_type in ('update', 'delete')
 
     when not matched
-     --and DBT_INTERNAL_SOURCE.dbt_change_type = 'insert'
-        then insert ({{ insert_cols_csv |upper }})
+        then insert ({{ insert_cols_csv | upper }})
         values ({{ insert_cols_csv | upper}})
+        where DBT_INTERNAL_SOURCE.dbt_change_type = 'insert'
     ;
 {% endmacro %}
\ No newline at end of file
